@@ -6,7 +6,7 @@
 import fnmatch
 import logging
 import os
-from typing import Optional, List
+from typing import List, Optional
 from zipfile import ZipFile
 
 from mvt.common.module import MVTModule
